Learn R Programming

thestats (version 0.1.0)

depts_en: Information in English about departments, faculties in Turkish universities.

Description

A dataset containing type, faculty, deparment information in English for 198 universties in Turkey .

Usage

depts_en

Arguments

Format

A data frame with 25652 rows and 7 variables:

id

University id

year

year of the data is anounced

type

type of university (state or private)

program_code

official program id of the department

university

name of the university

faculty

name of the faculty

department

name of the department