Learn R Programming

thestats (version 0.1.0)

regions_cities_en: Information in English about universities in Turkey.

Description

A dataset containing region, city, type and website information in English for 198 universties in Turkey .

Usage

regions_cities_en

Arguments

Format

A data frame with 198 rows and 6 variables:

id

University id

university

name of the university

type

type of university (state or private)

city

name of the city where the university is located

region

name of the region where the university is located

website

website url of the university